@@ -20,7 +20,7 @@ class menupromp(object):
         return [self.clase.__dict__[x] for x in [value for value in self.clase.__dict__ if value[:4] == "opt_"]], [x[4:] for x in [value for value in self.clase.__dict__ if value[:4] == "opt_"]]
 
     def genfuncs(self):
-        return {ids+1: value for ids, value in enumerate(self.__dir__()[0])}
+        return {str(ids+1): value for ids, value in enumerate(self.__dir__()[0])}
 
     def genmenu(self):
         return {ids+1: value for ids, value in enumerate(self.__dir__()[1])}
@@ -32,7 +32,7 @@ def newMenu(obj, intro=""):
         print(intro)
         m.banner(m.genmenu())
         try:
-            opt = int(input("\n"+m.promp))
+            opt = input("\n"+m.promp)
             m.genfuncs().get(opt)()
         except TypeError:
             print(m.excepterror)
